<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>RDHPIPlayStream</name>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No such file or directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No output stream available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stream is already open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown RDHpiPlayStream Error:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDHPIRecordStream</name>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create/open file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Input stream unavailable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stream is already open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown RDHpiRecordStream Error:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDHPISoundCard</name>
    <message>
        <source>Input Stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Output Stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Input Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Output Port</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
